jQuery.sap.declare('sas.fscf.CustomBootTask');

jQuery.sap.require('sas.hc.ui.core.Core');
jQuery.sap.require('sas.hc.ui.core.BootTask');
jQuery.sap.require('sap.ui.core.format.NumberFormat');

sas.hc.ui.core.BootTask.extend("sas.fscf.CustomBootTask", {
    name: 'SAS-fscf-CustomBootTask'
});

sas.fscf.CustomBootTask.prototype.run = function () {
	// Do stuff here to participate in the boot strap
	// Generally stuff you want to do before application view is instantiated.

    jQuery.sap.includeStyleSheet("resources/sas/fscf/fscf.css");

    sas.config.initialSessionMaxInActiveInterval = sas.config.sessionMaxInActiveInterval;
    sas.config.initialSessionTimeoutWarningDuration = sas.config.sessionTimeoutWarningDuration;
    sas.fscf.NLS_BASE = 'sas.fscf';
    sas.fscf.MESSAGE_BUNDLE_PATH = 'resources/sas/fscf/messagebundle.properties';
    sas.fscf.rb = sap.ui.getCore().getLibraryResourceBundle(sas.fscf.NLS_BASE);
    sas.fscf.floatFormatter = sap.ui.core.format.NumberFormat.getFloatInstance();
    sas.fscf.percentFormatter = sap.ui.core.format.NumberFormat.getPercentInstance({minFractionDigits:2,maxFractionDigits:2});
    sas.fscf.enableNewRuleFeatures = sas.config.get('fscf').ruleEnableGuided;
    sas.fscf.enableDynamicLookupLists = sas.config.get('fscf').enableDynamicLookupLists;
    sas.fscf.RULE_APPROACH_GUIDED = 0;
    sas.fscf.RULE_APPROACH_CODING = 1;
    sas.fscf.MESSAGE_TYPE_INFO = 0;
    sas.fscf.MESSAGE_TYPE_COMPLETE = 1;
    sas.fscf.MESSAGE_TYPE_WARNING = 2;
    sas.fscf.MESSAGE_TYPE_ERROR = 3;
	sas.fscf.inlineMessageClasses = ["inlineMessageInfo","inlineMessageComplete","inlineMessageWarning","inlineMessageError"];
	sas.fscf.inlineMessageIconContents = ["&#xf330;","&#xf160;","&#xf018;","&#xf22f;"];
	sas.fscf.showInlineMessage =  function(parentId, type, message, bCenter, customIconContent, bTransparent) {
		var $p = $("#" + parentId);
    	if ($p.length == 0) {
    		return;
    	}
		$p.find('.inlineMessage').remove();
    	if (type == undefined) {
    		type = sas.fscf.MESSAGE_TYPE_INFO;
    	}
		var markup = [];
		markup[markup.length] = '<div class="inlineMessage ' + sas.fscf.inlineMessageClasses[type] + ((bTransparent) ? ' inlineMessageTransparent' : '') + '">';
		markup[markup.length] = '<div class="inlineMessageIcon">';
		markup[markup.length] = '<span class="sapUiBtnIco sapUiBtnIcoL sapUiIcon" style="font-family: sas-icons;" data-sap-ui-icon-content="' + ((customIconContent) ? customIconContent : sas.fscf.inlineMessageIconContents[type]) + '"></span>';
		markup[markup.length] = '</div>';
		markup[markup.length] = '<div class="inlineMessageMessage">';
		markup[markup.length] = message;
		markup[markup.length] = '</div>';
		if (!bTransparent) {
			markup[markup.length] = '<div class="inlineMessageClose">';
			markup[markup.length] = '<a href="#" title="' + sas.fscf.rb.getText("fcm.application.close.txt") + '" onclick="this.parentNode.parentNode.style.display=\'none\';">';
			markup[markup.length] = '<span class="sapUiBtnIco sapUiBtnIcoL sapUiIcon" style="font-family: sas-icons;" data-sap-ui-icon-content="&#xf10c;"></span>';
			markup[markup.length] = '</a>';
			markup[markup.length] = '</div>';
		}
		markup[markup.length] = '</div>';
        $p.prepend(markup.join(''));
        if (bCenter) {
        	var $m = $p.find('.inlineMessage').first();
        	$m.css({position : 'absolute', zIndex : '1000', margin: '0px', left: '33%', top: '25%', maxWidth: '33%'});
        }
    };
    sas.fscf.hideInlineMessage = function(parentId) {
    	var $p = $('#' + parentId);
    	if ($p.length == 0) {
    		return;
    	}
		$p.find('.inlineMessage').remove();
    };

/*    sas.fscf.helpUrlLookup = {
    	"ITabReports":"a_reports.htm",
    	"ITabStrategies":"a_strategies.htm",
    	"ITabTemplates":"a_templates.htm",
    	"ITabNotifications":"a_notifications.htm",
    	"ITabGroups":"a_groupTab.htm",
    	"ITabUsers":"a_users.htm",
    	"ITabMultiorg":"a_multiorgTab.htm",
    	"ITabAnalystWorkstation":"fcmAppMain.htm",
    	"ITabPreference":"a_preferences.htm",
    	"ITabRules":"r_rulesView.htm",
    	"ITabConsole":"r_consoleView.htm",
    	"ITabLoader":"a_incrloader.htm"
    };*/
    sas.fscf.resizeContainers = function () {
		$("#sas_hc_content .sasFCHContent").css("overflow", "hidden");
		$("#sas_hc_content .sasFCHContent").height(
				$("#sas_hc_content .sasFCHContent").parent().height() -
				$("#sas_hc_content .sasFHCHeader").height());
    	$("#sas_hc_content .sapMITBContainerContent").height(
    			$("#sas_hc_content .sasFCHContent").height() -
    			$("#sas_hc_content .sapMITH").height() - 3);
    	var $iframe = $("iframe[name='overview']");
    	if ($iframe.length) {
    		var h = Math.floor($iframe.parent().height() -
    				($iframe.position().top - $iframe.parent().position().top)) - 6;
    		$iframe.css("height", h + "px")
    	}
    	$iframe = $("iframe[name='detail']");
    	if ($iframe.length) {
    		var h = Math.floor($iframe.parent().height() -
    				($iframe.position().top - $iframe.parent().position().top)) - 6;
    		$iframe.css("height", h + "px")
    	}
    };
    $(document).ready(sas.fscf.resizeContainers);
    $(window).resize(sas.fscf.resizeContainers);
	sas.fscf.sessionBindIFrames = function () {
		$("iframe").load(function (e) {
			sas.fscf.sessionUserActivity();
			$(e.target).contents().click(function (e) {
				sas.fscf.sessionUserActivity();
				return true;
			});
		});
	};
	sas.fscf.setCookie = function(name,value,expireDate)
	{
		if(!value || value == '')
		{
			removeCookie(name,'');
			return;
		}

		var theDate;
		if(expireDate)
		{
			theDate = expireDate;
		}
		else
		{
			theDate = new Date();
			theDate.setDate(theDate.getDate()+1);
		}

		document.cookie = name + "=" + escape(value) + ";expires=" + theDate.toGMTString();
	};
	sas.fscf.getCookie = function(name,defaultValue)
	{
		var cookies = document.cookie.split("; ");
		for(var i=0; i < cookies.length; i++)
		{
			var theCookie = cookies[i].split("=");
			if (name == theCookie[0])
				return unescape(theCookie[1]);
		}

		return defaultValue;
	};
};

// register with sas hc
(function () {
    sas.hc.ui.getCore().registerTask(new sas.fscf.CustomBootTask());
}())
